#!/usr/bin/env python
# Storm mini Evolution clone by Damien Tanner (dctanner@xoasis.com)      
#
# This file is part of Storm.
#
#    Storm is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Storm is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with Storm; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from gtk import *
from modules.xmlparse import *
import string, os, time

class Calendar:
	def __init__(self, parent):
		self.parent = parent
		self.cmap = self.parent.window.get_colormap()
		date = time.strftime("%d %m %Y", time.gmtime(time.time()))
		self.cal_date = string.split(date)
		print self.cal_date
		self.cal_time = ['00','00']

		frame=GtkFrame()
		frame.set_usize(-1, -1)
		frame.set_shadow_type("GTK_SHADOW_ETCHED_IN")
		frame.set_label("Calendar")
		frame.set_label_align(0, -1)
		frame.show()
		self.frame=frame
		frame.show()

		vbox = GtkVBox()
		frame.add(vbox)
		vbox.show()

		hbox = GtkHBox()
		vbox.pack_start(hbox, expand=FALSE)
		hbox.show()

		# make the toobar
		toolbar2 = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar2.set_button_relief(RELIEF_NONE)
		toolbar2.set_space_size(10)
		hbox.pack_start(toolbar2, fill=TRUE)
		# add the evolution pixmaps to the toolbar
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/new.xpm")
		toolbar2.append_item(None, 'Create a new appointment', None, GtkPixmap(pix, mask), self.new_appointment)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/edit.xpm")
		toolbar2.append_item(None, 'Edit the selected appointment', None, GtkPixmap(pix, mask), self.edit_appointment)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/trash.xpm")
		toolbar2.append_item(None, 'Delete the selected appointment', None, GtkPixmap(pix, mask), self.delete_appointment)

		toolbar2.show()

		# make the toobar
		toolbar3 = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar3.set_button_relief(RELIEF_NONE)
		toolbar3.set_space_size(10)
		hbox.pack_start(toolbar3, fill=TRUE)
		# add the evolution pixmaps to the toolbar
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/left.xpm")
		toolbar3.append_item(None, 'Create a new appointment', None, GtkPixmap(pix, mask), self.back_one_day)

		self.date_label = GtkLabel(time.strftime("%a, %b %d %Y", (int(self.cal_date[2]), int(self.cal_date[1]), int(self.cal_date[0]), 0, 0, 0, 0, 0, 0)))
		date_button = GtkButton()
		date_button.set_relief(RELIEF_NONE)
		date_button.add(self.date_label)
		date_button.connect("clicked", self.select_date_from_calendar)
		toolbar3.append_widget(date_button, 'Select Date from Calendar', '')
		self.date_label.show()
		date_button.show()

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/right.xpm")
		toolbar3.append_item(None, 'Delete the selected appointment', None, GtkPixmap(pix, mask), self.forward_one_day)

		toolbar3.show()

		cscroll = GtkScrolledWindow()
		cscroll.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
		vbox.pack_start(cscroll)
		cscroll.show()

		clist=GtkCList(2)
		cscroll.add(clist)
		clist.connect("select-row" , self.select_appointment)
		clist.set_flags(CAN_FOCUS)
		clist.set_usize(-1, 87)
		clist.set_column_title(0, "Time")
		clist.set_column_title(1, "Summery")
		clist.set_column_width(0, 35)
		clist.set_column_width(1, 90)
		clist.set_selection_mode(SELECTION_SINGLE)
		clist.column_titles_hide()
		clist.show()
		self.clist = clist

		scroll = GtkScrolledWindow()
		scroll.set_policy(POLICY_NEVER, POLICY_ALWAYS)
		self.scroll = scroll
		vbox.pack_start(scroll)
		self.text_scroll = scroll

		text = GtkText()
		self.text = text
		text.set_editable(FALSE)
		scroll.add(text)
		text.show()
		self.text = text

		self.selected_appointment = -1
		self.selected_cal_row = 0

		v = '00'
		j = 0

		# - Add a list times for every 30 minues of the day
		while j < 24:
			y = string.rjust(str(j), 2).replace(' ', '0') + ':' + v
			self.clist.append([y, ''])

			if v == '00':
				v = '30'
			elif v == '30':
				v = '00'
				j = j + 1

		# - Read the appointments xml file
		xml = XmlParse()
		self.xml_appointments = xml.parse_xml_file(self.parent.config[2] + '/data/appointments.xml', 'appointment')
		self.appointment = []

		for xml_appointment in self.xml_appointments:
			self.appointment.append([xml.xml_get_text(xml_appointment, "summary"),[xml.xml_get_text(xml_appointment, "start-time-hour"), xml.xml_get_text(xml_appointment, "start-time-minute")],[xml.xml_get_text(xml_appointment, "end-time-hour"), xml.xml_get_text(xml_appointment, "end-time-minute")],[xml.xml_get_text(xml_appointment, "date-day"), xml.xml_get_text(xml_appointment, "date-month"), xml.xml_get_text(xml_appointment, "date-year")],[xml.xml_get_text(xml_appointment, "alarm-status"), xml.xml_get_text(xml_appointment, "alarm-id")], xml.xml_get_text(xml_appointment, "description")])

 		self.update_list()

	def select_appointment(self, *args):
		'''This is called when the user clicks on an appointment from the list. It then adds the info to a GtkText.'''

		self.selected_cal_row = args[1]
		self.selected_appointment = self.clist_ref[args[1]]
		cal_time_text = string.split(self.clist.get_text(args[1],0), ":")
		self.cal_time = string.split(self.clist.get_text(args[1],0), ":")

		if self.selected_appointment != -1:
			self.text.delete_text(0,-1)
			self.text.insert(None,None,None,self.appointment[self.selected_appointment][0] + "\n" + self.appointment[self.selected_appointment][5])
			self.text_scroll.show()
		else:
			self.text_scroll.hide()

	def update_list(self):
		'''Update the CList with appointments.'''

		# - Set some gdk colors and varibles for looping
		clist_color = self.cmap.alloc("grey87");
		clist_color_dark = self.cmap.alloc("grey80");
		clist_color_white = self.cmap.alloc("white");
		self.clist_ref = []

		x = 0
		b = 0
		q = 0
		title = 1
		blank = 0

		# - For every 30 minutes of a 24 hour day: check if there's an appointment scheduled then
		while x < 48:
			# More looping varibles
			z = 0
			stop = 0
			blank = 1

			# - Loop through every appointment and see if it's scheduled for the current time in the loop
			while z < len(self.appointment):

				if self.appointment[z][3][0] == self.cal_date[0] and self.appointment[z][3][1] == self.cal_date[1] and self.appointment[z][3][2] ==  self.cal_date[2] and stop == 0:
					# - Work out exactly how many minues since 00:00 it is supposed to start and end
					start_min = int(self.appointment[z][1][0]) * 60
					end_min = int(self.appointment[z][2][0]) * 60
					start_min = start_min + int(self.appointment[z][1][1])
					end_min = end_min + int(self.appointment[z][2][1])

					# - Make sure it falls between the current loop time
					if start_min - 30 <= q and end_min >= q:

						# - Check if this is the first row of the appointment: if so make it colored darker and add a title
						if title == 1:
							self.clist.set_text(x,1,self.appointment[z][0])
							self.clist.set_background(x, clist_color_dark)
							self.clist_ref.append(z)
							title = 0
							blank = 0
							#stop = 1
						# - If not just color it a light grey
						else:
							self.clist.set_background(x, clist_color)
							self.clist_ref.append(z)
							blank = 0
							#stop = 1

					# - If the next loop round will be the end of this current appointment make sure the next one has a title etc...
					elif end_min + 30 >= q and end_min - 30 <= q:
						title = 1
						print "BLANK"
				z = z + 1

			# - If there's no text for the current loop time: just leave it alone (not that I'm actualy going to leave it alone)
			if blank == 1:
				self.clist.set_text(x,1,'')
				self.clist.set_background(x, clist_color_white)
				self.clist_ref.append(-1)
				title = 1

			x = x + 1
			q = q + 30

		# - Select the last row we selected
		self.clist.select_row(self.selected_cal_row,0)

	def new_appointment(self, *args):
		'''Open up a new appointment window.'''
		self.do_appointment("new")

	def edit_appointment(self, *args):
		'''Edit the currently selected appointment.'''
		self.do_appointment("edit")

	def delete_appointment(self, *args):
		'''Delete the currently selected appointment.'''

		# - If an alarm was scheduled: make sure we delete it
		if self.appointment[self.selected_appointment][4][0] == 'yes':
			os.system("uschedulerm " + self.appointment[self.selected_appointment][4][1])

		# - Delete the actualy appointment infomation
		del self.appointment[self.selected_appointment]

		# - Update the xml, list and today
		self.update_xml()
		self.update_list()
		self.parent.today.update_today()

	def save_appointment(self, *args):
		'''Saves the just created appointment.'''

		# - If the alarm box is ticked: schedule it with uschedule and get the alarm id
		if self.alarm_check.get_active() == TRUE:
			alarm_status = 'yes'
			usche = string.split(os.popen("uschedulecmd storm-alarm").read())
			alarm_id  = usche[7]
			os.system("uschedule " + alarm_id + " '" + self.cal_date[2] + "-" + self.cal_date[1] + "-" + self.cal_date[0] + " " + string.rjust(self.start_time_combo_hour.entry.get_text(), 2).replace(' ', '0') + ":" + string.rjust(self.start_time_combo_minute.entry.get_text(), 2).replace(' ', '0') + ":00'")
		else:
			alarm_status = 'no'
			alarm_id = ''

		# - Add the info for the new alarm
		self.appointment.append([self.summary_entry.get_text(), [self.start_time_combo_hour.entry.get_text(), self.start_time_combo_minute.entry.get_text()], [self.end_time_combo_hour.entry.get_text(), self.end_time_combo_minute.entry.get_text()], [self.cal_date[0], self.cal_date[1], self.cal_date[2]], [alarm_status, alarm_id], self.description_text.get_chars(0, -1)])

		# - Update the xml, list and today
		self.update_xml()
		self.update_list()
		self.appointment_window.hide()
		self.parent.today.update_today()

	def save_edited_appointment(self, *args):
		'''Saves and edited appointment.'''

		# - Replace the old values with the new ones
		self.appointment[self.selected_appointment][0] = self.summary_entry.get_text()
		self.appointment[self.selected_appointment][1][0] = self.start_time_combo_hour.entry.get_text()
		self.appointment[self.selected_appointment][1][1] = self.start_time_combo_minute.entry.get_text()
		self.appointment[self.selected_appointment][2][0] = self.end_time_combo_hour.entry.get_text()
		self.appointment[self.selected_appointment][2][1] = self.end_time_combo_minute.entry.get_text()
		self.appointment[self.selected_appointment][5] = self.description_text.get_chars(0, -1)

		# - If there was a previously scheduled alarm, delete it first
		if self.appointment[self.selected_appointment][4][0] == 'yes':
			os.system("uschedulerm " + self.appointment[self.selected_appointment][4][1])

		# - Schedule the alarm if needed
		if self.alarm_check.get_active() == TRUE:
			# - Get the uschedule command id
			usche = string.split(os.popen("uschedulecmd storm-alarm").read())
			self.appointment[self.selected_appointment][4][1] = usche[7]
			os.system("uschedule " + self.appointment[self.selected_appointment][4][1] + " '" + self.cal_date[2] + "-" + self.cal_date[1] + "-" + self.cal_date[0] + " " + string.rjust(self.start_time_combo_hour.entry.get_text(), 2).replace(' ', '0') + ":" + string.rjust(self.start_time_combo_minute.entry.get_text(), 2).replace(' ', '0') + ":00'")
			self.appointment[self.selected_appointment][4][0] = 'yes'
		else:
			self.appointment[self.selected_appointment][4][0] = 'no'
			self.appointment[self.selected_appointment][4][1] = ''

		# - Update the xml, list and today
		self.update_xml()
		self.update_list()
		self.select_appointment(None, self.selected_appointment)
		self.appointment_window.hide()
		self.parent.today.update_today()

	def do_appointment(self, type):
		'''Open up the appointment new/edit window.'''

		# - If the currently selected time is blank make a new appointment
		if self.selected_appointment == -1:
			type = "new"

		# our main gtk window
		window = GtkWindow(WINDOW_TOPLEVEL)
		self.appointment_window = window
		window.connect("delete_event", window.hide)
		window.set_title("Storm - Appointment")
		if screen_width() > 300:
			window.set_usize(280, 240)
		else:
			window.set_usize(240, 280)
		window.show()

		vbox = GtkVBox()
		window.add(vbox)
		vbox.show()

		# make the toobar
		toolbar = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar.set_button_relief(RELIEF_NONE)
		toolbar.set_space_size(10)
		vbox.pack_start(toolbar, expand=FALSE)
		toolbar.show()
		# add the evolution pixmaps to the toolbar
		if type == "edit":
			pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
			toolbar.append_item(None, 'Save the current appointment', None, GtkPixmap(pix, mask), self.save_edited_appointment)
		else:
			pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
			toolbar.append_item(None, 'Save the current appointment', None, GtkPixmap(pix, mask), self.save_appointment)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
		toolbar.append_item(None, 'Close this window', None, GtkPixmap(pix, mask), window.hide)


		# - Make a list of hours and minutes for time selection
		time_hours = []
		time_minutes = []
		t = 0
		for t in range (1,24):
			time_hours.append(string.rjust(str(t), 2).replace(' ', '0'))
		t = 0
		while t < 60:
			time_minutes.append(string.rjust(str(t), 2).replace(' ', '0'))
			t = t + 5

		table1=GtkTable(5, 2)
		vbox.pack_start(table1)
		table1.show()
		table1.set_usize(-1, -1)
		table1.set_row_spacings(0)
		table1.set_col_spacings(0)
		label1=GtkLabel()
		table1.attach(label1, 0, 1, 0, 1, FILL, 0, 0, 0)
		label1.set_usize(-1, -1)
		label1.set_text("Summary")
		label1.set_justify(JUSTIFY_CENTER)
		label1.set_alignment(0, 0.5)
		label1.set_padding(0, 0)
		label1.show()
		self.label1=label1
		label2=GtkLabel()
		table1.attach(label2, 0, 1, 1, 2, FILL, 0, 0, 0)
		label2.set_usize(-1, -1)
		label2.set_text("Start")
		label2.set_justify(JUSTIFY_CENTER)
		label2.set_alignment(0, 0.5)
		label2.set_padding(0, 0)
		label2.show()
		self.label2=label2
		label3=GtkLabel()
		table1.attach(label3, 0, 1, 2, 3, FILL, 0, 0, 0)
		label3.set_usize(-1, -1)
		label3.set_text("End")
		label3.set_justify(JUSTIFY_CENTER)
		label3.set_alignment(0, 0.5)
		label3.set_padding(0, 0)
		label3.show()
		self.label3=label3
		label4=GtkLabel()
		table1.attach(label4, 0, 1, 3, 4, FILL, 0, 0, 0)
		label4.set_usize(-1, -1)
		label4.set_text("Alarm")
		label4.set_justify(JUSTIFY_CENTER)
		label4.set_alignment(0, 0.5)
		label4.set_padding(0, 0)
		label4.show()
		self.label4=label4
		label5=GtkLabel()
		table1.attach(label5, 0, 1, 4, 5, FILL, 0, 0, 0)
		label5.set_usize(-1, -1)
		label5.set_text("Description")
		label5.set_justify(JUSTIFY_CENTER)
		label5.set_alignment(0, 0.5)
		label5.set_padding(0, 0)
		label5.show()
		self.label5=label5

		summary_entry=GtkEntry()
		table1.attach(summary_entry, 1, 2, 0, 1, EXPAND, 0, 0, 0)
		summary_entry.set_flags(CAN_FOCUS)
		summary_entry.set_usize(160, -1)
		summary_entry.set_editable(TRUE)
		summary_entry.set_visibility(TRUE)
		summary_entry.set_max_length(0)
		if type == "edit":
			summary_entry.set_text(self.appointment[self.selected_appointment][0])
		summary_entry.show()
		self.summary_entry=summary_entry

		start_time_hbox = GtkHBox()
		table1.attach(start_time_hbox, 1, 2, 1, 2, EXPAND|FILL, 0, 0, 0)
		start_time_hbox.show()

		start_time_combo_hour = GtkCombo()
		start_time_combo_hour.set_usize(45, -1)
		start_time_hbox.pack_start(start_time_combo_hour, expand=FALSE)
		t = 0
		start_time_combo_hour.set_popdown_strings(time_hours)
		if type == "edit":
			start_time_combo_hour.entry.set_text(self.appointment[self.selected_appointment][1][0])
		else:
			start_time_combo_hour.entry.set_text(self.cal_time[0])
		start_time_combo_hour.show()
		self.start_time_combo_hour = start_time_combo_hour

		start_time_combo_minute = GtkCombo()
		start_time_combo_minute.set_usize(45, -1)
		start_time_hbox.pack_start(start_time_combo_minute, expand=FALSE)
		start_time_combo_minute.set_popdown_strings(time_minutes)
		if type == "edit":
			start_time_combo_minute.entry.set_text(self.appointment[self.selected_appointment][1][1])
		else:
			start_time_combo_minute.entry.set_text(self.cal_time[1])
		start_time_combo_minute.show()
		self.start_time_combo_minute = start_time_combo_minute

		end_time_hbox = GtkHBox()
		table1.attach(end_time_hbox, 1, 2, 2, 3, EXPAND|FILL, 0, 0, 0)
		end_time_hbox.show()

		end_time_combo_hour = GtkCombo()
		end_time_combo_hour.set_usize(45, -1)
		end_time_hbox.pack_start(end_time_combo_hour, expand=FALSE)
		t = 0
		end_time_combo_hour.set_popdown_strings(time_hours)
		if type == "edit":
			end_time_combo_hour.entry.set_text(self.appointment[self.selected_appointment][2][0])
		else:
			end_time_combo_hour.entry.set_text(self.cal_time[0])
		end_time_combo_hour.show()
		self.end_time_combo_hour = end_time_combo_hour

		end_time_combo_minute = GtkCombo()
		end_time_combo_minute.set_usize(45, -1)
		end_time_hbox.pack_start(end_time_combo_minute, expand=FALSE)
		end_time_combo_minute.set_popdown_strings(time_minutes)
		if type == "edit":
			end_time_combo_minute.entry.set_text(self.appointment[self.selected_appointment][2][1])
		else:
			end_time_combo_minute.entry.set_text(self.cal_time[1])
		end_time_combo_minute.show()
		self.end_time_combo_minute = end_time_combo_minute

		alarm_check = GtkCheckButton()
		table1.attach(alarm_check, 1, 2, 3, 4, EXPAND|FILL, 0, 0, 0)
		if type == "edit":
			if self.appointment[self.selected_appointment][4][0] == 'yes':
				alarm_check.set_active(TRUE)
		if os.path.exists("/usr/bin/uschedule") == -1:
				alarm_check.set_sensitive(FALSE)
		alarm_check.show()
		self.alarm_check = alarm_check

		scrolledwindow1=GtkScrolledWindow()
		table1.attach(scrolledwindow1, 1, 2, 4, 5, EXPAND, 0, 0, 0)
		scrolledwindow1.set_usize(160, 70)
		scrolledwindow1.set_policy(POLICY_NEVER, POLICY_AUTOMATIC)
		description_text=GtkText()
		scrolledwindow1.add(description_text)
		description_text.set_flags(CAN_FOCUS)
		description_text.set_usize(160, 70)
		description_text.set_editable(TRUE)
		if type == "edit":
			description_text.insert(None,None,None,self.appointment[self.selected_appointment][5])
		description_text.show()
		self.description_text=description_text
		scrolledwindow1.show()
		self.scrolledwindow1=scrolledwindow1

	def select_date_from_calendar(self, *args):
		'''Select date from graphical calendar.'''

		# our main gtk window
		window = GtkWindow(WINDOW_TOPLEVEL)
		self.calendar_select_window = window
		window.connect("delete_event", window.hide)
		window.set_title("Storm - Calendar")
		window.set_usize(200, 140)
		window.show()

		calendar = GtkCalendar()
		calendar.select_month(int(self.cal_date[1]) - 1, int(self.cal_date[2]))
		calendar.select_day(int(self.cal_date[0]))
		calendar.connect("day-selected-double-click", self.change_date)
		window.add(calendar)
		calendar.show()
		self.select_calendar = calendar

	def change_date(self, *args):
		'''Change date entry's to the selected date.'''

		# - Get the date from the graphical calendar
		year, month, day = self.select_calendar.get_date()
		# - It gives us the months starting at 0, but we want them to start at 1
		month = month + 1

		# - Make sure the numbers have a 0 on the front if needed
		self.cal_date[0] = string.rjust(str(day), 2).replace(' ', '0')
		self.cal_date[1] = string.rjust(str(month), 2).replace(' ', '0')
		self.cal_date[2] = str(year)

		# - Set the text of our entry box
		print self.cal_date
		self.date_label.set_text(time.strftime("%a, %b %d %Y", (year, month, day, 0, 0, 0, 0, 0, 0)))
		self.update_list()
		self.calendar_select_window.hide()

	def back_one_day(self, *args):
		'''Sets the selected date back by one day.'''

		secs = time.mktime((int(self.cal_date[2]), int(self.cal_date[1]), int(self.cal_date[0]), 0, 0, 0, 0, 0, 0))
		secs = secs - 86400
		date = time.strftime("%d %m %Y", time.gmtime(secs))

		self.cal_date = string.split(date)
		self.date_label.set_text(time.strftime("%a, %b %d %Y", (int(self.cal_date[2]), int(self.cal_date[1]), int(self.cal_date[0]), 0, 0, 0, 0, 0, 0)))
		self.update_list()

	def forward_one_day(self, *args):
		'''Sets the selected date forward by one day.'''

		secs = time.mktime((int(self.cal_date[2]), int(self.cal_date[1]), int(self.cal_date[0]), 0, 0, 0, 0, 0, 0))
		secs = secs + 86400
		date = time.strftime("%d %m %Y", time.gmtime(secs))

		self.cal_date = string.split(date)
		self.date_label.set_text(time.strftime("%a, %b %d %Y", (int(self.cal_date[2]), int(self.cal_date[1]), int(self.cal_date[0]), 0, 0, 0, 0, 0, 0)))
		self.update_list()

	def update_xml(self):
		'''Update the calendar xml storage file.'''

		file = open(self.parent.config[2] + '/data/appointments.xml', 'w')

		x = 0
		while x < len(self.appointment):
			print self.appointment[x]
			file.write('<appointment>\n<summary>' + self.appointment[x][0] + '</summary>\n<start-time-hour>' + self.appointment[x][1][0] + '</start-time-hour>\n<start-time-minute>' + self.appointment[x][1][1] + '</start-time-minute>\n<end-time-hour>' + self.appointment[x][2][0] + '</end-time-hour>\n<end-time-minute>' + self.appointment[x][2][1] + '</end-time-minute>\n<date-day>' + self.appointment[x][3][0] + '</date-day>\n<date-month>' + self.appointment[x][3][1] + '</date-month>\n<date-year>' + self.appointment[x][3][2] + '</date-year>\n<alarm-status>' + self.appointment[x][4][0] + '</alarm-status>\n<alarm-id>' + str(self.appointment[x][4][1]) + '</alarm-id>\n<description>' + self.appointment[x][5] + '</description>\n</appointment>\n\n')
			x = x + 1

		file.close
