#!/usr/bin/env python
# Storm mini Evolution clone by Damien Tanner (dctanner@xoasis.com)      
#
# This file is part of Storm.
#
#    Storm is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Storm is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with Storm; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from gtk import *
from modules.xmlparse import *
import string, time, os

class Contacts:
	def __init__(self, parent):
		self.parent = parent
		self.cmap = self.parent.window.get_colormap()

		frame=GtkFrame()
		frame.set_usize(-1, -1)
		frame.set_shadow_type("GTK_SHADOW_ETCHED_IN")
		frame.set_label("Contacts")
		frame.set_label_align(0, -1)

		vpaned = GtkVPaned()
		frame.add(vpaned)
		vpaned.show()

		vbox = GtkVBox()
		vpaned.pack1(vbox)
		vbox.show()

		hbox2 = GtkHBox()
		vbox.pack_start(hbox2, expand=FALSE)
		hbox2.show()

		self.find_button = GtkButton("Find")
		self.find_button.connect("clicked", self.do_find)
		hbox2.pack_start(self.find_button, expand=FALSE)

		self.find_entry = GtkEntry()
		hbox2.pack_start(self.find_entry, expand=FALSE)

		# make the toobar
		toolbar = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		self.toolbar = toolbar
		toolbar.set_button_relief(RELIEF_NONE)
		toolbar.set_space_size(10)
		hbox2.pack_start(toolbar, expand=FALSE)
		toolbar.show()
		# add the evolution pixmaps to the toolbar
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/new.xpm")
		toolbar.append_item(None, 'Create a new contact', None, GtkPixmap(pix, mask), self.new_contact)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/edit.xpm")
		toolbar.append_item(None, 'Edit the selected contact', None, GtkPixmap(pix, mask), self.edit_contact)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/trash.xpm")
		toolbar.append_item(None, 'Delete the selected contact', None, GtkPixmap(pix, mask), self.delete_contact)

		toolbar2 = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar2.set_button_relief(RELIEF_NONE)
		toolbar2.set_space_size(10)
		hbox2.pack_end(toolbar2, expand=FALSE)
		toolbar2.show()
		# add the evolution pixmaps to the toolbar
		self.phone_menubar = GtkMenuBar()
		self.phone_menubar.set_shadow_type(SHADOW_NONE)
		self.phone_menubar.set_sensitive(FALSE)
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/phone.xpm")
		phone_menuitem = GtkMenuItem()
		phone_pixmap = GtkPixmap(pix,mask)
		phone_menuitem.add(phone_pixmap)
		phone_pixmap.show()
		phone_menuitem.show()
		self.phone_menuitem = phone_menuitem
		self.phone_menubar.append(phone_menuitem)
		toolbar2.append_widget(self.phone_menubar, 'Dial Number', '')
		self.phone_menubar.show()

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/find.xpm")
		toolbar2.append_item(None, 'Find Contacts', None, GtkPixmap(pix, mask), self.show_find)
		self.find_state = FALSE

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/list.xpm")
		toolbar2.append_item(None, 'Show Column Names', None, GtkPixmap(pix, mask), self.clist_titles_change)

		cscroll = GtkScrolledWindow()
		cscroll.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
		vbox.pack_start(cscroll)
		cscroll.show()

		clist=GtkCList(2)
		cscroll.add(clist)
		clist.connect("select-row" , self.select_contact)
		clist.connect("click-column" , self.select_clist_column)
		clist.set_flags(CAN_FOCUS)
		clist.set_usize(-1, 87)
		clist.set_column_title(0, "Name")
		clist.set_column_title(1, "Email")
		clist.set_column_width(0, 100)
		clist.set_column_width(1, 80)
		clist.set_selection_mode(SELECTION_SINGLE)
		clist.column_titles_hide()
		self.clist_titles_state = FALSE
		clist.show()
		self.clist=clist
		frame.show()
		self.frame=frame

		self.clist_color = self.cmap.alloc("grey87");

		scroll = GtkScrolledWindow()
		scroll.set_policy(POLICY_NEVER, POLICY_ALWAYS)
		self.scroll = scroll
		vpaned.pack2(scroll)
		scroll.show()

		text = GtkText()
		self.text = text
		text.set_editable(FALSE)
		scroll.add(text)
		text.show()

		# - Parse the contacts xml file
		xml = XmlParse()

		# - Get the config for contacts info fields
		self.xml_contacts_config = xml.parse_xml_file(self.parent.config[2] + '/config/contacts', 'field')
		self.contacts_config = []

		# - Put the config into a varible
		for xml_contact_field in self.xml_contacts_config:
			self.contacts_config.append([xml.xml_get_text(xml_contact_field, "type"), xml.xml_get_text(xml_contact_field, "display-name"), xml.xml_get_text(xml_contact_field, "xml-name")])

		# - Now actualy start to parse the contacts
		xml = XmlParse()
		self.xml_contacts = xml.parse_xml_file(self.parent.config[2] + '/data/contacts.xml', 'contact')
		self.contact = []

		# - For each contact get the data for the corisponding contacts config field name
		for xml_contact in self.xml_contacts:

			xml_contact_parts = []

			for xml_field_name in self.contacts_config:
				xml_field = xml.xml_get_text(xml_contact, xml_field_name[2])
				xml_contact_parts.append(xml_field)

			self.contact.append(xml_contact_parts)

		self.update_list(self.clist)

	def update_list(self, clist, column=0):
		'''Updates the contacts list with the latest info.'''

		x = 0
		v = 0

		# - Sort the contacts if needed
		self.contact.sort(lambda x, y, column=column: cmp(x[column], y[column]))

		# - Freeze the clist just for good looks
		clist.freeze()
		clist.clear()

		# - For each contact see if the current data is a name or email, if so insert it into the clist
		while x < len(self.contact):
			z = 0

			while z < len(self.contacts_config):

				if self.contacts_config[z][2] == "name":
					cname = self.contact[x][z]

				elif self.contacts_config[z][2] == "email":
					cemail = self.contact[x][z]

				z = z + 1

			headers = [cname, cemail]
			clist.append(headers)

			if v == 0:
				clist.set_background(x, self.clist_color)
				v = 1
			else:
				v = 0
			x = x + 1

		clist.thaw()

	def clist_titles_change(self, *args):
		'''Called when the column titles button is pressed.'''

		# - If the column titles are hidden, show them, and vice versa
		if self.clist_titles_state == FALSE:
			self.clist.column_titles_show()
			self.clist_titles_state = TRUE
		else:
			self.clist.column_titles_hide()
			self.clist_titles_state = FALSE

	def select_clist_column(self, *args):
		'''Called when a comumn title is clicked, then sorts the list by it.'''

		self.update_list(self.clist, args[1])

	def show_find(self, *args):
		'''Shows to find contacts box.'''

		# - If it's hidden, show it, vice versa
		if self.find_state == FALSE:
			self.toolbar.hide()
			self.find_button.show()
			self.find_entry.show()

			# - Restores the backed up contacts info
			self.tmp_contact = self.contact
			self.find_state = TRUE
		else:
			self.find_button.hide()
			self.find_entry.hide()
			self.toolbar.show()

			# - Backs up the current contacts info
			self.contact = self.tmp_contact
			self.update_list(self.clist)
			self.find_state = FALSE

	def do_find(self, *args):
		'''Finds a contact.'''

		# - Get the search entyr box text
		find_str = self.find_entry.get_text()
		# - Make the entry box blank now, ready for another search
		self.find_entry.set_text("")

		x = 0
		# - Clear the clist ready for the found contacts
		self.clist.clear()
		self.new_contact = []

		# - Check every contact to see if it matches the searhc string
		while x < len(self.tmp_contact):
			z = 0
			found = 0

			# - Loop through every field of the contact seaching for the string
			while z < len(self.contacts_config):
				if string.find(self.tmp_contact[x][z], find_str) != -1:
					found = 1
				z = z + 1

			# - If it found a match insert it into the list
			if found == 1:
				self.new_contact.append(self.tmp_contact[x])
			x = x + 1

		# - Set the contact info of the matches as the current
		self.contact = self.new_contact
		# - Update the list with the found contacts
		self.update_list(self.clist)

	def select_contact(self, *args):
		'''Called when a contact is selected from the list.'''

		# - Set the dtmf dialer menu off by default
		self.phone_menubar.set_sensitive(FALSE)
		# - Overide any existing menu entrys
		self.phone_menu = GtkMenu()

		# - Freeze the text box and delete the existing text
		self.text.freeze()
		self.text.delete_text(0, -1)
		self.selected_contact = args[1]
		x = 0

		# - For each contacts config field
		while x < len(self.contacts_config):

			# - Insert the contact info for the current contacts config field into the text box
			if self.contact[self.selected_contact][x] != '':
				self.text.insert(None,None,None,self.contacts_config[x][1] + ": " + self.contact[self.selected_contact][x] + "\n")

				# - If there's a phone number add it to the dtmf dial menu
				if string.find(self.contacts_config[x][2], "phone") != -1:
					number_menuitem = GtkMenuItem(self.contacts_config[x][1])
					number_menuitem.connect("activate", self.dial_number, self.contact[self.selected_contact][x])
					self.phone_menu.append(number_menuitem)
					number_menuitem.show()
					self.phone_menubar.set_sensitive(TRUE)

			x = x + 1

		# - Set the text boxs scroll to the top
		vadjust = self.scroll.get_vadjustment()
		vadjust.set_value(0)
		self.text.thaw()

		# - Show the dtmf dial menu and add the new menu items
		self.phone_menu.show()
		self.phone_menuitem.set_submenu(self.phone_menu)

	def new_contact(self, *args):
		'''Open the new contact window.'''

		self.do_contact("new")

	def edit_contact(self, *args):
		'''Edit the selected contact.'''

		self.do_contact("edit")

	def delete_contact(self, *args):
		'''Delete the selected contact.'''

		del self.contact[self.selected_contact]
		self.text.delete_text(0, -1)
		self.update_xml()
		self.update_list(self.clist)

	def save_contact(self, *args):
		'''Save a new contact.'''

		x = 0
		contact_parts = []

		# - For each contacts config field, add it to the list of contacts
		while x < len(self.contacts_config):
			if self.contacts_config[x][0] == "entry" or self.contacts_config[x][0] == "date":
				contact_parts.append(self.contact_entry[x].get_text())

			elif self.contacts_config[x][0] == "text":
				contact_parts.append(self.contact_entry[x].get_chars(0, -1))
			x = x + 1

		self.update_xml()
		self.contact.append(contact_parts)
		self.update_list(self.clist)
		self.contact_window.hide()

	def save_edited_contact(self, *args):
		'''Save an edited contact.'''

		x = 0

		# - For each contacts config field, add it to the list of contacts
		while x < len(self.contacts_config):

			if self.contacts_config[x][0] == "entry" or self.contacts_config[x][0] == "date":
				self.contact[self.selected_contact][x] = self.contact_entry[x].get_text()

			elif self.contacts_config[x][0] == "text":
				self.contact[self.selected_contact][x] = self.contact_entry[x].get_chars(0, -1)

			x = x + 1

		self.update_xml()
		self.update_list(self.clist)
		self.select_contact(None, self.selected_contact)
		self.contact_window.hide()

	def do_contact(self, type, cname='', cemail=''):
		'''Main gui contact window. Used for making and editing contacts.'''

		# our main gtk window
		window = GtkWindow(WINDOW_TOPLEVEL)
		self.contact_window = window
		window.connect("delete_event", window.hide)
		window.set_title("Storm - Contact")
		if screen_width() > 300:
			window.set_usize(280, 240)
		else:
			window.set_usize(240, 280)
		window.show()

		vbox = GtkVBox()
		window.add(vbox)
		vbox.show()

		# make the toobar
		toolbar = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar.set_button_relief(RELIEF_NONE)
		toolbar.set_space_size(10)
		vbox.pack_start(toolbar, expand=FALSE)
		toolbar.show()
		# add the evolution pixmaps to the toolbar
		if type == "edit":
			pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
			toolbar.append_item(None, 'Save the current contact', None, GtkPixmap(pix, mask), self.save_edited_contact)
		else:
			pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
			toolbar.append_item(None, 'Save the current contact', None, GtkPixmap(pix, mask), self.save_contact)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
		toolbar.append_item(None, 'Close this window', None, GtkPixmap(pix, mask), window.hide)

		scroll = GtkScrolledWindow()
		scroll.set_policy(POLICY_NEVER, POLICY_AUTOMATIC)
		vbox.pack_start(scroll)
		scroll.show()

		self.contact_entry = []
		x = 0
		y = 1
		z = 0

		# - Main table set to the size of the number contacts config fields
		table1=GtkTable(len(self.contacts_config), 2)
		scroll.add_with_viewport(table1)
		table1.set_usize(-1, -1)
		table1.set_row_spacings(0)
		table1.set_col_spacings(0)

		# - Loop through all the contact config fields adding labels
		while z < len(self.contacts_config):

			# - If the contacts config field is a date type, add a nice select date from calendar button
			if self.contacts_config[z][0] == "date":
				appointment_tips = GtkTooltips()
				label=GtkButton(self.contacts_config[z][1])
				appointment_tips.set_tip(label, 'Select date from calendar')
				label.connect("clicked", self.select_date_from_calendar, z)
				table1.attach(label, 0, 1, x, y, FILL, 0, 0, 0)
				label.show()

			# - If not, just add a normal label
			else:
				label=GtkLabel()
				table1.attach(label, 0, 1, x, y, FILL, 0, 0, 0)
				label.set_usize(-1, -1)
				label.set_text(self.contacts_config[z][1])
				label.set_justify(JUSTIFY_CENTER)
				label.set_alignment(0, 0.5)
				label.set_padding(0, 0)
				label.show()

			x = x + 1
			y = y + 1
			z = z + 1

		x = 0
		y = 1
		z = 0

		# - Loop through all the contact config fields adding entry and text boxes
		while z < len(self.contacts_config):

			# - If the contacts config field is a date or entry type, just add an entry box
			if self.contacts_config[z][0] == "entry" or self.contacts_config[z][0] == "date":
				entry=GtkEntry()
				table1.attach(entry, 1, 2, x, y, EXPAND, 0, 0, 0)
				entry.set_flags(CAN_FOCUS)
				entry.set_usize(120, -1)
				entry.set_editable(TRUE)
				entry.set_visibility(TRUE)
				entry.set_max_length(0)

				# - If we're editing a contact, insert the currnet data into the entry boxes
				if type == "edit":
					entry.set_text(self.contact[self.selected_contact][z])

				# - If  we're adding a contact from an email add the values passed
				if self.contacts_config[z][2] == "name" and type != "edit":
					entry.set_text(cname)
				elif self.contacts_config[z][2] == "email" and type != "edit":
					entry.set_text(cemail)

				entry.show()
				self.contact_entry.append(entry)

			# - If not, add a text box
			elif self.contacts_config[z][0] == "text":
				scrolledwindow1=GtkScrolledWindow()
				table1.attach(scrolledwindow1, 1, 2, x, y, EXPAND, 0, 0, 0)
				scrolledwindow1.set_usize(120, 60)
				scrolledwindow1.set_policy(POLICY_NEVER, POLICY_AUTOMATIC)
				scrolledwindow1.show()
				text=GtkText()
				scrolledwindow1.add(text)
				text.set_flags(CAN_FOCUS)
				text.set_usize(120, 60)
				text.set_editable(TRUE)

				# - If we're editing a contact, insert the currnet data into the text boxes
				if type == "edit":
					text.insert(None,None,None,self.contact[self.selected_contact][3])
				text.show()
				self.contact_entry.append(text)

			x = x + 1
			y = y + 1
			z = z + 1

		table1.show()

	def select_date_from_calendar(self, *args):
		'''Opens up a select date from calendar window.'''

		# our main gtk window
		window = GtkWindow(WINDOW_TOPLEVEL)
		self.calendar_select_window = window
		window.connect("delete_event", window.hide)
		window.set_title("Storm - Calendar")
		window.set_usize(200, 140)
		window.show()

		calendar = GtkCalendar()
		calendar.connect("day-selected-double-click", self.change_date)
		window.add(calendar)
		calendar.show()
		self.select_calendar = calendar
		self.calendar_entry = args[1]

	def change_date(self, *args):
		'''Called when a date is selected form the calendar. Then adds the date to the specified entry box.'''

		year, month, day = self.select_calendar.get_date()

		# - The calendar gives us the month starting at 0, but we want it to start at 1
		month = month + 1
		self.contact_entry[self.calendar_entry].set_text(time.strftime("%a, %b %d %Y", (year, month, day, 0, 0, 0, 0, 0, 0)))
		self.calendar_select_window.hide()

	def dial_number(self, args, number=''):
		'''Used a seperate dtmfdial program to dial dtmf tones to a nearby phone.'''

		# - If the dtmfdial program is installed, dial the specified number
		if os.path.exists("/usr/bin/dtmfdial") != -1:
			os.system("dtmfdial " + str(number))

	def update_xml(self):
		'''Updates the contact xml file.'''

		file = open(self.parent.config[2] + '/data/contacts.xml', 'w')
		x = 0

		# - Loops through all the contacts and add them to the xml file
		while x < len(self.contact):
			z = 0
			file.write('<contact>\n')

			while z < len(self.contacts_config):
				file.write('<' + self.contacts_config[z][2] + '>' + self.contact[x][z] + '</' + self.contacts_config[z][2] + '>\n')
				z = z + 1

			file.write('</contact>\n\n')
			x = x + 1

		file.close

	def exit(self, *args):
		'''Saves xml changes before we exit.'''

		self.update_xml()
