#!/usr/bin/env python
# Storm mini Evolution clone by Damien Tanner (dctanner@xoasis.com)      
#
# This file is part of Storm.
#
#    Storm is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Storm is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with Storm; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from gtk import *
import string, os

class Prefs:
	def __init__(self, parent):
		self.parent = parent

	def show_config(self, *args):
		# our main gtk window
		window = GtkWindow(WINDOW_TOPLEVEL)
		self.parent.config_window = window
		window.connect("delete_event", window.hide)
		window.set_title("Storm - Prefs")
		if screen_width() > 300:
			window.set_usize(280, 240)
		else:
			window.set_usize(240, 280)
		window.show()

		vbox = GtkVBox()
		window.add(vbox)
		vbox.show()

		storm_file = open(os.environ['HOME'] + '/.storm', 'r')
		raw = storm_file.read()
		storm_config = string.split(raw, '\n')
		storm_file.close()
		self.storm_config = storm_config
		sync_file = open(self.parent.config[2] + '/config/sync', 'r')
		raw = sync_file.read()
		sync_config = string.split(raw, '\n')
		sync_file.close()
		smtp_file = open(self.parent.config[2] + '/config/smtp', 'r')
		raw = smtp_file.read()
		smtp_config = string.split(raw, '\n')
		smtp_file.close()
		sig_file = open(self.parent.config[2] + '/config/sig', 'r')
		sig = sig_file.read()
		sig_file.close()

		toolbar = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar.set_button_relief(RELIEF_NONE)
		toolbar.set_space_size(10)
		vbox.pack_start(toolbar, expand=FALSE)
		toolbar.show()
		# add the evolution pixmaps to the toolbar
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
		toolbar.append_item(None, 'Save preferences', None, GtkPixmap(pix, mask), self.save_config)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
		toolbar.append_item(None, 'Close this window', None, GtkPixmap(pix, mask), window.hide)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/help.xpm")
		toolbar.append_item(None, 'About', None, GtkPixmap(pix, mask), self.parent.help.about)

		scrolledwindow1=GtkScrolledWindow()
		vbox.pack_start(scrolledwindow1)
		scrolledwindow1.set_usize(-1, -1)
		scrolledwindow1.set_policy(POLICY_NEVER, POLICY_ALWAYS)
		viewport1=GtkViewport()
		scrolledwindow1.add_with_viewport(viewport1)
		viewport1.set_usize(-1, -1)
		vbox1=GtkVBox()
		viewport1.add(vbox1)
		vbox1.set_usize(-1, -1)
		vbox1.set_homogeneous(FALSE)
		vbox1.set_spacing(0)

		frame1=GtkFrame()
		vbox1.pack_start(frame1, TRUE, TRUE, 0)
		frame1.set_usize(-1, -1)
		frame1.set_shadow_type("GTK_SHADOW_ETCHED_IN")
		frame1.set_label("Mail")
		frame1.set_label_align(0, -1)
		table1=GtkTable(2, 3)
		frame1.add(table1)
		table1.set_usize(-1, -1)
		table1.set_row_spacings(0)
		table1.set_col_spacings(0)
		label1=GtkLabel()
		table1.attach(label1, 0, 1, 0, 1, FILL, 0, 0, 0)
		label1.set_usize(-1, -1)
		label1.set_text("Name")
		label1.set_justify(JUSTIFY_CENTER)
		label1.set_alignment(0, 0.5)
		label1.set_padding(0, 0)
		label1.show()
		self.label1=label1
		label2=GtkLabel()
		table1.attach(label2, 0, 1, 1, 2, FILL, 0, 0, 0)
		label2.set_usize(-1, -1)
		label2.set_text("Email")
		label2.set_justify(JUSTIFY_CENTER)
		label2.set_alignment(0, 0.5)
		label2.set_padding(0, 0)
		label2.show()
		self.label2=label2
		label11=GtkLabel()
		table1.attach(label11, 0, 1, 2, 3, FILL, 0, 0, 0)
		label11.set_usize(-1, -1)
		label11.set_text("Signature ")
		label11.set_justify(JUSTIFY_CENTER)
		label11.set_alignment(0, 0.5)
		label11.set_padding(0, 0)
		label11.show()
		self.label11=label11
		entry1=GtkEntry()
		table1.attach(entry1, 1, 2, 0, 1, EXPAND, 0, 0, 0)
		entry1.set_flags(CAN_FOCUS)
		entry1.set_usize(120, -1)
		entry1.set_editable(TRUE)
		entry1.set_visibility(TRUE)
		entry1.set_max_length(0)
		entry1.set_text(storm_config[0])
		entry1.show()
		self.entry1=entry1
		entry2=GtkEntry()
		table1.attach(entry2, 1, 2, 1, 2, EXPAND, 0, 0, 0)
		entry2.set_flags(CAN_FOCUS)
		entry2.set_usize(120, -1)
		entry2.set_editable(TRUE)
		entry2.set_visibility(TRUE)
		entry2.set_max_length(0)
		entry2.set_text(storm_config[1])
		entry2.show()
		self.entry2=entry2
		scroll1 = GtkScrolledWindow()
		table1.attach(scroll1, 1, 2, 2, 3, EXPAND, 0, 0, 0)
		scroll1.set_usize(120, -1)
		scroll1.set_policy(POLICY_NEVER, POLICY_AUTOMATIC)
		scroll1.show()
		self.scroll1 = scroll1
		text1 = GtkText()
		scroll1.add(text1)
		text1.set_usize(120, -1)
		text1.set_editable(TRUE)
		text1.insert(None, None, None,sig)
		text1.show()
		self.text1 = text1
		table1.show()
		self.table1=table1
		frame1.show()
		self.frame1=frame1
		frame2=GtkFrame()
		vbox1.pack_start(frame2, TRUE, TRUE, 0)
		frame2.set_usize(-1, -1)
		frame2.set_shadow_type("GTK_SHADOW_ETCHED_IN")
		frame2.set_label("Sync")
		frame2.set_label_align(0, -1)
		table2=GtkTable(4, 2)
		frame2.add(table2)
		table2.set_usize(-1, -1)
		table2.set_row_spacings(0)
		table2.set_col_spacings(0)
		label3=GtkLabel()
		table2.attach(label3, 0, 1, 0, 1, FILL, 0, 0, 0)
		label3.set_usize(-1, -1)
		label3.set_text("Username")
		label3.set_justify(JUSTIFY_CENTER)
		label3.set_alignment(0, 0.5)
		label3.set_padding(0, 0)
		label3.show()
		self.label3=label3
		label4=GtkLabel()
		table2.attach(label4, 0, 1, 1, 2, FILL, 0, 0, 0)
		label4.set_usize(-1, -1)
		label4.set_text("Host IP")
		label4.set_justify(JUSTIFY_CENTER)
		label4.set_alignment(0, 0.5)
		label4.set_padding(0, 0)
		label4.show()
		self.label4=label4
		label5=GtkLabel()
		table2.attach(label5, 0, 1, 2, 3, FILL, 0, 0, 0)
		label5.set_usize(-1, -1)
		label5.set_text("Incoming")
		label5.set_justify(JUSTIFY_CENTER)
		label5.set_alignment(0, 0.5)
		label5.set_padding(0, 0)
		label5.show()
		self.label5=label5
		label6=GtkLabel()
		table2.attach(label6, 0, 1, 3, 4, FILL, 0, 0, 0)
		label6.set_usize(-1, -1)
		label6.set_text("Outgoing")
		label6.set_justify(JUSTIFY_CENTER)
		label6.set_alignment(0, 0.5)
		label6.set_padding(0, 0)
		label6.show()
		self.label6=label6
		entry4=GtkEntry()
		table2.attach(entry4, 1, 2, 1, 2, EXPAND, 0, 0, 0)
		entry4.set_flags(CAN_FOCUS)
		entry4.set_usize(120, -1)
		entry4.set_editable(TRUE)
		entry4.set_visibility(TRUE)
		entry4.set_max_length(0)
		entry4.set_text(sync_config[1])
		entry4.show()
		self.entry4=entry4
		entry5=GtkEntry()
		table2.attach(entry5, 1, 2, 2, 3, EXPAND, 0, 0, 0)
		entry5.set_flags(CAN_FOCUS)
		entry5.set_usize(120, -1)
		entry5.set_editable(TRUE)
		entry5.set_visibility(TRUE)
		entry5.set_max_length(0)
		entry5.set_text(sync_config[2])
		entry5.show()
		self.entry5=entry5
		entry6=GtkEntry()
		table2.attach(entry6, 1, 2, 3, 4, EXPAND, 0, 0, 0)
		entry6.set_flags(CAN_FOCUS)
		entry6.set_usize(120, -1)
		entry6.set_editable(TRUE)
		entry6.set_visibility(TRUE)
		entry6.set_max_length(0)
		entry6.set_text(sync_config[3])
		entry6.show()
		self.entry6=entry6
		entry3=GtkEntry()
		table2.attach(entry3, 1, 2, 0, 1, EXPAND, 0, 0, 0)
		entry3.set_flags(CAN_FOCUS)
		entry3.set_usize(120, -1)
		entry3.set_editable(TRUE)
		entry3.set_visibility(TRUE)
		entry3.set_max_length(0)
		entry3.set_text(sync_config[0])
		entry3.show()
		self.entry3=entry3
		table2.show()
		self.table2=table2
		frame2.show()
		self.frame2=frame2
		frame4=GtkFrame()
		vbox1.pack_start(frame4, TRUE, TRUE, 0)
		frame4.set_usize(-1, -1)
		frame4.set_shadow_type("GTK_SHADOW_ETCHED_IN")
		frame4.set_label("SMTP")
		frame4.set_label_align(0, -1)
		table4=GtkTable(1, 2)
		frame4.add(table4)
		table4.set_usize(-1, -1)
		table4.set_row_spacings(0)
		table4.set_col_spacings(0)
		label12=GtkLabel()
		table4.attach(label12, 0, 1, 0, 1, FILL, 0, 0, 0)
		label12.set_usize(-1, -1)
		label12.set_text("Server")
		label12.set_justify(JUSTIFY_CENTER)
		label12.set_alignment(0, 0.5)
		label12.set_padding(0, 0)
		label12.show()
		self.label12=label12
		entry12=GtkEntry()
		table4.attach(entry12, 1, 2, 0, 1, EXPAND, 0, 0, 0)
		entry12.set_flags(CAN_FOCUS)
		entry12.set_usize(120, -1)
		entry12.set_editable(TRUE)
		entry12.set_visibility(TRUE)
		entry12.set_max_length(0)
		entry12.set_text(smtp_config[0])
		entry12.show()
		self.entry12=entry12
		table4.show()
		self.table4=table4
		frame4.show()
		self.frame4=frame4
		vbox1.show()
		self.vbox1=vbox1
		viewport1.show()
		self.viewport1=viewport1
		scrolledwindow1.show()
		self.scrolledwindow1=scrolledwindow1

	def save_config(self, *args):
		text1 = self.entry1.get_text()
		text2 = self.entry2.get_text()
		text3 = self.entry3.get_text()
		text4 = self.entry4.get_text()
		text5 = self.entry5.get_text()
		text6 = self.entry6.get_text()
		text12 = self.entry12.get_text()
		storm_file = open(os.environ['HOME'] + '/.storm', 'w')
		storm_file.write(text1 + '\n' + text2 + '\n' + self.storm_config[2])
		storm_file.close()
		sync_file = open(self.parent.config[2] + '/config/sync', 'w')
		sync_file.write(text3 + '\n' + text4 + '\n' + text5 + '\n' + text6)
		sync_file.close()
		smtp_file = open(self.parent.config[2] + '/config/smtp', 'w')
		smtp_file.write(text12)
		smtp_file.close()
		sig_file = open(self.parent.config[2] + '/config/sig', 'w')
		sig = sig_file.write(self.text1.get_chars(0, -1))
		sig_file.close()
		self.parent.get_config()
		self.parent.config_window.hide()
