#!/usr/bin/env python
# Storm mini Evolution clone by Damien Tanner (dctanner@xoasis.com)      
#
# This file is part of Storm.
#
#    Storm is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Storm is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with Storm; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from gtk import *
from modules.xmlparse import *
import string

class Tasks:
	def __init__(self, parent):
		self.parent = parent
		self.cmap = self.parent.window.get_colormap()

		frame=GtkFrame()
		frame.set_usize(-1, -1)
		frame.set_shadow_type("GTK_SHADOW_ETCHED_IN")
		frame.set_label("Tasks")
		frame.set_label_align(0, -1)
		frame.show()
		self.frame=frame
		frame.show()
		
		vpane = GtkVPaned()
		frame.add(vpane)
		vpane.show()

		vbox = GtkVBox()
		vpane.pack1(vbox)
		vbox.show()

		hbox = GtkHBox()
		vbox.pack_start(hbox, expand=FALSE)
		hbox.show()

		toolbar1 = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar1.set_button_relief(RELIEF_NONE)
		toolbar1.set_space_size(10)
		hbox.pack_start(toolbar1, expand=FALSE)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/new.xpm")
		toolbar1.append_item(None, 'Create a new task', None, GtkPixmap(pix, mask), self.new_task)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/edit.xpm")
		toolbar1.append_item(None, 'Edit the selected task', None, GtkPixmap(pix, mask), self.edit_task)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/trash.xpm")
		toolbar1.append_item(None, 'Delete the selected task', None, GtkPixmap(pix, mask), self.delete_task)

		toolbar1.show()

		toolbar2 = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar2.set_button_relief(RELIEF_NONE)
		toolbar2.set_space_size(10)
		hbox.pack_end(toolbar2, expand=FALSE)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/tick.xpm")
		toolbar2.append_item(None, 'Set the task as done', None, GtkPixmap(pix, mask), self.done_task)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
		toolbar2.append_item(None, 'Set the task as not yet done', None, GtkPixmap(pix, mask), self.cancel_task)

		toolbar2.show()

		cscroll = GtkScrolledWindow()
		cscroll.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
		vbox.pack_start(cscroll)
		cscroll.show()

		clist=GtkCList(3)
		cscroll.add(clist)
		clist.connect("select-row" , self.select_task)
		clist.set_flags(CAN_FOCUS)
		clist.set_usize(-1, 87)
		clist.set_column_title(0, "Status")
		clist.set_column_title(1, "Summary")
		clist.set_column_title(2, "Priority")
		clist.set_column_width(0, 18)
		clist.set_column_width(1, 90)
		clist.set_column_width(2, 20)
		clist.set_selection_mode(SELECTION_SINGLE)
		clist.column_titles_hide()
		clist.show()
		self.clist = clist

		scroll = GtkScrolledWindow()
		scroll.set_policy(POLICY_NEVER, POLICY_ALWAYS)
		self.scroll = scroll
		vpane.pack2(scroll)

		text = GtkText()
		self.text = text
		text.set_editable(FALSE)
		scroll.add(text)
		text.show()
		scroll.show()
		self.text = text
		
		# - Read the tasks xml file
		xml = XmlParse()
		self.xml_tasks = xml.parse_xml_file(self.parent.config[2] + '/data/tasks.xml', 'task')
		self.task = []

		for xml_task in self.xml_tasks:
			self.task.append([xml.xml_get_text(xml_task, "summary"), xml.xml_get_text(xml_task, "description"), xml.xml_get_text(xml_task, "priority"), xml.xml_get_text(xml_task, "status")])

 		self.update_list()

	def update_list(self):
		'''Update the CList with tasks.'''
		
		self.clist.clear()
		
		# - Sort the tasks by priority
		self.task.sort(lambda x, y: cmp(x[2], y[2]))

		x = 0
		
		# - Loop through all the tasks
		while x < len(self.task):
			
			# - Make the correct status pixmap
			if int(self.task[x][3]) == 1:
				pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/tick.xpm")
			else:
				pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
			pixmap = GtkPixmap(pix, mask)
			
			# - Insert the status pixmap, summary and priority into the clist
			self.clist.append(['', self.task[x][0], self.task[x][2]])
			self.clist.set_pixmap(x,0,pixmap)
			
			# - Work out the correct gdk color for the priority
			color_num = int(self.task[x][2])*3 + 60
			
			# - Color the current clist row that color
			clist_color = self.cmap.alloc("grey" + str(color_num));
			self.clist.set_background(x, clist_color)
			
			x = x + 1
			
	def select_task(self, *args):
		'''Called when the user selects a task.'''
		
		# - Let the rest of the program know what task has been selected
		self.selected_task = args[1]
		
		# - Insert the tasks description into the text box
		self.text.freeze()
		self.text.delete_text(0,-1)
		self.text.insert(None,None,None,self.task[self.selected_task][0] + '\n' + self.task[self.selected_task][1])	
		self.text.thaw()
		
	def done_task(self, *args):
		'''Sets the task as done and changes the clist status pixmap.'''
		
		# - Change the task status to done (1)
		self.task[self.selected_task][3] = '1'
		
		# - Change the clist status pixmap to a tick
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/tick.xpm")
		pixmap = GtkPixmap(pix, mask)
		self.clist.set_pixmap(self.selected_task,0,pixmap)
		
		# - Update xml
		self.update_xml()
		
	def cancel_task(self, *args):
		'''Sets the task as not done and changes the clist status pixmap.'''
		
		# - Change the task status to not done (0)
		self.task[self.selected_task][3] = '0'
		
		# - Change the clist status pixmap to cancel
		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
		pixmap = GtkPixmap(pix, mask)
		self.clist.set_pixmap(self.selected_task,0,pixmap)
		
		# - Update xml
		self.update_xml()
		
	def new_task(self, *args):
		'''Makes a new task.'''
		
		self.do_task("new")
		
	def edit_task(self, *args):
		'''Edits the currently selecet task.'''
		
		self.do_task("edit")
		
	def delete_task(self, *args):
		'''Deletes the currently selected task.'''
		
		# - Delete the tasks text from the text box
		self.text.delete_text(0,-1)
		
		# - Delete the tasks data
		del self.task[self.selected_task]
		
		# - Remove it from the clist
		self.clist.remove(self.selected_task)
		
		# - Update xml
		self.update_xml()
		
	def save_task(self, *args):
		'''Saves the just created task.'''
		
		# - Get the data for the new task
		self.task.append([self.summary_entry.get_text(), self.description_text.get_chars(0,-1), self.priority_combo.entry.get_text(), '0'])

		# - Update the xml, list and today
		self.update_xml()
		self.update_list()
		self.task_window.hide()
		self.parent.today.update_today()
		
	def save_edited_task(self, *args):
		'''Saves an edited task.'''
		
		self.task[self.selected_task][0] = self.summary_entry.get_text()
		self.task[self.selected_task][1] = self.description_text.get_chars(0,-1)
		self.task[self.selected_task][2] = self.priority_combo.entry.get_text()
		
		# - Update the xml, list and today
		self.update_xml()
		self.update_list()
		self.task_window.hide()
		self.parent.today.update_today()

	def do_task(self, type):
		'''Open up the task new/edit window.'''

		window = GtkWindow(WINDOW_TOPLEVEL)
		self.task_window = window
		window.connect("delete_event", window.hide)
		window.set_title("Storm - Task")
		if screen_width() > 300:
			window.set_usize(280, 240)
		else:
			window.set_usize(240, 280)
		window.show()

		vbox = GtkVBox()
		window.add(vbox)
		vbox.show()

		toolbar = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		toolbar.set_button_relief(RELIEF_NONE)
		toolbar.set_space_size(10)
		vbox.pack_start(toolbar, expand=FALSE)
		toolbar.show()
		
		if type == "edit":
			pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
			toolbar.append_item(None, 'Save the current appointment', None, GtkPixmap(pix, mask), self.save_edited_task)
		else:
			pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/save.xpm")
			toolbar.append_item(None, 'Save the current appointment', None, GtkPixmap(pix, mask), self.save_task)

		pix, mask = create_pixmap_from_xpm(self.parent.window, None, self.parent.config[2] + "/pixmaps/cancel.xpm")
		toolbar.append_item(None, 'Close this window', None, GtkPixmap(pix, mask), window.hide)

		table1=GtkTable(3, 2)
		vbox.pack_start(table1)
		table1.show()
		table1.set_usize(-1, -1)
		table1.set_row_spacings(0)
		table1.set_col_spacings(0)
		label1=GtkLabel()
		table1.attach(label1, 0, 1, 0, 1, FILL, 0, 0, 0)
		label1.set_usize(-1, -1)
		label1.set_text("Summary")
		label1.set_justify(JUSTIFY_CENTER)
		label1.set_alignment(0, 0.5)
		label1.set_padding(0, 0)
		label1.show()
		self.label1=label1
		label2=GtkLabel()
		table1.attach(label2, 0, 1, 1, 2, FILL, 0, 0, 0)
		label2.set_usize(-1, -1)
		label2.set_text("Priority")
		label2.set_justify(JUSTIFY_CENTER)
		label2.set_alignment(0, 0.5)
		label2.set_padding(0, 0)
		label2.show()
		self.label2=label2
		label3=GtkLabel()
		table1.attach(label3, 0, 1, 2, 3, FILL, 0, 0, 0)
		label3.set_usize(-1, -1)
		label3.set_text("Description")
		label3.set_justify(JUSTIFY_CENTER)
		label3.set_alignment(0, 0.5)
		label3.set_padding(0, 0)
		label3.show()
		self.label3=label3
		
		summary_entry=GtkEntry()
		table1.attach(summary_entry, 1, 2, 0, 1, EXPAND, 0, 0, 0)
		summary_entry.set_flags(CAN_FOCUS)
		summary_entry.set_usize(160, -1)
		summary_entry.set_editable(TRUE)
		summary_entry.set_visibility(TRUE)
		summary_entry.set_max_length(0)
		if type == "edit":
			summary_entry.set_text(self.task[self.selected_task][0])
		summary_entry.show()
		self.summary_entry=summary_entry

		priority_combo = GtkCombo()
		priority_combo.set_usize(45, -1)
		table1.attach(priority_combo, 1, 2, 1, 2, 0, 0, 0, 0)
		prioritys = []
		for priority in range(1,11):
			prioritys.append(str(priority))
		priority_combo.set_popdown_strings(prioritys)
		if type == "edit":
			priority_combo.entry.set_text(self.task[self.selected_task][2])
		priority_combo.show()
		self.priority_combo = priority_combo

		scrolledwindow1=GtkScrolledWindow()
		table1.attach(scrolledwindow1, 1, 2, 2, 3, EXPAND, 0, 0, 0)
		scrolledwindow1.set_usize(160, 70)
		scrolledwindow1.set_policy(POLICY_NEVER, POLICY_AUTOMATIC)
		description_text=GtkText()
		scrolledwindow1.add(description_text)
		description_text.set_flags(CAN_FOCUS)
		description_text.set_usize(160, 70)
		description_text.set_editable(TRUE)
		if type == "edit":
			description_text.insert(None,None,None,self.task[self.selected_task][1])
		description_text.show()
		self.description_text=description_text
		scrolledwindow1.show()
		self.scrolledwindow1=scrolledwindow1

	def update_xml(self):
		'''Update the tasks xml storage file.'''

		file = open(self.parent.config[2] + '/data/tasks.xml', 'w')

		x = 0
		while x < len(self.task):
			file.write('<task>\n<summary>' + self.task[x][0] + '</summary>\n<description>' + self.task[x][1] + '</description>\n<priority>' + self.task[x][2] + '</priority>\n<status>' + self.task[x][3] + '</status>\n</task>\n\n')
			x = x + 1

		file.close

