#!/usr/bin/env python
# Storm mini Evolution clone by Damien Tanner (dctanner@xoasis.com)      
#
# This file is part of Storm.
#
#    Storm is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Storm is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with Storm; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from gtk import *
import string, rfc822, re, os, sys, time, poplib, smtplib
from modules.stormload import *
from modules.mail import *
from modules.today import *
from modules.notes import *
from modules.contacts import *
from modules.calendar import *
from modules.help import *
from modules.sync import *
from modules.prefs import *
from modules.tasks import *

# main class for the gui, other classes handle diffrent sub functions such as Mail and Contacts
class Storm:
	def __init__(self):
		# our main gtk window
		self.window = GtkWindow(WINDOW_TOPLEVEL)
		self.window.connect("delete_event", self.quit)
		self.window.set_title("Storm v0.5")
		if screen_width() > 300:
			self.window.set_usize(280, 240)
		else:
			self.window.set_usize(240, 280)

		# read storm config file
		self.get_config()
		# show a nice loading popup
		self.loading = StormLoad(self)
		while events_pending(): mainiteration()
		# start by importing the other classes
		self.contacts = Contacts(self)
		while events_pending(): mainiteration()
		self.loading.today_pixmap.show()
		self.mail = Mail(self)
		while events_pending(): mainiteration()
		self.loading.calendar_pixmap.show()
		self.calendar = Calendar(self)
		while events_pending(): mainiteration()
		self.loading.notes_pixmap.show()
		self.notes = Notes(self)
		while events_pending(): mainiteration()
		self.loading.inbox_pixmap.show()
		self.sync = Sync(self)
		self.prefs = Prefs(self)
		while events_pending(): mainiteration()
		self.loading.contacts_pixmap.show()
		self.today = Today(self)
		self.help = Help(self)
		self.tasks = Tasks(self)
		while events_pending(): mainiteration()
		self.loading.tasks_pixmap.show()
		time.sleep(0.2)
		
		# close the loading window
		self.loading.window.hide()
		
		# Main vBox
		if screen_width() > 300:
			self.vbox = GtkHBox()
			self.window.add(self.vbox)
			self.vbox.show()

			hbox = GtkVBox()
			self.vbox.pack_start(hbox, expand=FALSE)
			hbox.show()
		else:
			self.vbox = GtkVBox()
			self.window.add(self.vbox)
			self.vbox.show()

			hbox = GtkHBox()
			self.vbox.pack_start(hbox, expand=FALSE)
			hbox.show()

		# make the toobar
		if screen_width() > 300:
			self.toolbar = GtkToolbar(ORIENTATION_VERTICAL, TOOLBAR_ICONS)
		else:
			self.toolbar = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		self.toolbar.set_button_relief(RELIEF_NONE)
		self.toolbar.set_space_size(10)
		hbox.pack_start(self.toolbar, expand=TRUE)
		self.toolbar.show()

		# make our notbook
		self.notebook = GtkNotebook()
		self.notebook.show()
		self.notebook.set_show_tabs(FALSE)
		self.notebook.set_show_border(FALSE)
		# add it to the vbox
		self.vbox.pack_start(self.notebook)
		# add a load of pages to it
		self.notebook.add(self.today.frame)
		self.notebook.add(self.mail.frame)
		self.notebook.add(self.calendar.frame)
		self.notebook.add(self.tasks.frame)
		self.notebook.add(self.contacts.frame)
		self.notebook.add(self.notes.frame)

		# add the evolution pixmaps to the toolbar
		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/storm-today-mini.xpm")
		self.toolbar.append_item(None, 'Today', None, GtkPixmap(pix, mask), self.show_today)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/storm-inbox-mini.xpm")
		self.toolbar.append_item(None, 'Inbox', None, GtkPixmap(pix, mask), self.show_mail)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/storm-calendar-mini.xpm")
		self.toolbar.append_item(None, 'Calendar', None, GtkPixmap(pix, mask), self.show_calendar)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/storm-tasks-mini.xpm")
		self.toolbar.append_item(None, 'Tasks', None, GtkPixmap(pix, mask), self.show_tasks)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/storm-contacts-mini.xpm")
		self.toolbar.append_item(None, 'Contacts', None, GtkPixmap(pix, mask), self.show_contacts)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/storm-notes-mini.xpm")
		self.toolbar.append_item(None, 'Notes', None, GtkPixmap(pix, mask), self.show_notes)

		# make another toobar for other items such as prefs, about and sync
		if screen_width() > 300:
			self.toolbar2 = GtkToolbar(ORIENTATION_VERTICAL, TOOLBAR_ICONS)
		else:
			self.toolbar2 = GtkToolbar(ORIENTATION_HORIZONTAL, TOOLBAR_ICONS)
		self.toolbar2.set_button_relief(RELIEF_NONE)
		self.toolbar2.set_space_size(10)
		hbox.pack_end(self.toolbar2, expand=FALSE)
		self.toolbar2.show()

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/prefs.xpm")
		self.toolbar2.append_item(None, 'Preferences', None, GtkPixmap(pix, mask), self.prefs.show_config)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/send-receive.xpm")
		self.toolbar2.append_item(None, 'Sync', None, GtkPixmap(pix, mask), self.sync.sync_menu)

		pix, mask = create_pixmap_from_xpm(self.window, None, self.config[2] + "/pixmaps/exit.xpm")
		self.toolbar2.append_item(None, 'Exit', None, GtkPixmap(pix, mask), self.quit)

	def show_today(self, *args):
		self.notebook.set_page(0)

	def show_mail(self, *args):
		self.notebook.set_page(1)

	def show_calendar(self, *args):
		self.notebook.set_page(2)

	def show_tasks(self, *args):
		self.notebook.set_page(3)

	def show_contacts(self, *args):
		self.notebook.set_page(4)

	def show_notes(self, *args):
		self.notebook.set_page(5)

	def get_config(self):
		# open up the storm config file
		file = open(os.environ['HOME'] + '/.storm', 'r')
		# read it
		lines = file.readlines()
		file.close()
		# assign varivles to the different lines
		self.config = []
		for line in lines:
			line = string.strip(line)
			self.config.append(line)

	def new_note(self, *args):
		self.show_notes()
		self.notes.new_note()

	def mainloop(self):
		# start up storm
		self.window.show()
		mainloop()

	def quit(self, *args):
		self.notes.exit()
		# quit storm
		os.system("rm -f /tmp/storm.lock")
		mainquit()

if os.path.exists("/tmp/storm.lock") <= 0:
	os.system("touch /tmp/storm.lock")
	storm = Storm()
	storm.mainloop()
else:
	print "Storm already seems to be running\nPlease delete /tmp/storm.lock manualy if this is not true"
